| Title: | GroundWater Spatiotemporal Data Analysis Tool (GWSDAT) |
|---|---|
| Description: | Shiny application for the analysis of groundwater monitoring data, designed to work with simple time-series data for solute concentration and ground water elevation, but can also plot non-aqueous phase liquid (NAPL) thickness if required. Also provides the import of a site basemap in GIS shapefile format. |
| Authors: | Wayne Jones [aut, cre] |
| Maintainer: | Wayne Jones <[email protected]> |
| License: | GPL-3 |
| Version: | 3.3.0 |
| Built: | 2026-06-06 07:29:53 UTC |
| Source: | https://github.com/waynegitshell/gwsdat |
createOptions creates a list with start options that can be modified
and passed as argument to launchApp.
createOptions(site_name = NULL)createOptions(site_name = NULL)
site_name |
An arbitrary string containing the name of the monitoring site. |
A list containing essential model parameters and start options.
opt <- createOptions("New Site 1") opt$PSplineVars$nseg <- 10 # modify model parameter for p-splines. opt$WellDataFilename <- 'path_to_concentration_file.csv' opt$WellCoordsFilename <- 'path_to_well_coordinate_file.csv' if(interactive()) { launchApp(opt) }opt <- createOptions("New Site 1") opt$PSplineVars$nseg <- 10 # modify model parameter for p-splines. opt$WellDataFilename <- 'path_to_concentration_file.csv' opt$WellCoordsFilename <- 'path_to_well_coordinate_file.csv' if(interactive()) { launchApp(opt) }
The shiny application can run in multi or single data mode. If no parameter is
specified with launchApp, the application starts in multi data mode, which
includes a data manager and several data import facilities. If the parameter session_file
was specified, the application launches in single data mode, which is limited to the
analysis of the data specified by session_file.
launchApp(GWSDAT_Options, session_file)launchApp(GWSDAT_Options, session_file)
GWSDAT_Options |
A list of start options created with |
session_file |
Path to .rds file containing a GWSDAT analysis session. |
None
if(interactive()) { launchApp(session_file = "path_to_GWSDAT_session.rds") # launch in single data mode. launchApp() # launch in multi data mode }if(interactive()) { launchApp(session_file = "path_to_GWSDAT_session.rds") # launch in single data mode. launchApp() # launch in multi data mode }